@@ -66,4 +66,9 @@ popd
 # And update the indirects
 $CREPO update-indirect -f
 
-test "$(cat .crepo/repo_a)" == "$COMMIT_C_HASH"
\ No newline at end of file
+test "$(cat .crepo/repo_a)" == "$COMMIT_C_HASH"
+
+# Now sync should say "already up-to-date"
+$CREPO sync 2>&1 | grep "already up-to-date"
+
+echo ALL GOOD
